# Copyright 2025 Som IT Cooperatiu SCCL - Nicolás Ramos <nicolas.ramos@somit.coop>
{
    'name': 'Project Template Origin',
    'version': '16.0.1.0.0',
    'summary': """Track project template origin in project copies""",
    'author': 'Som IT Cooperatiu SCCL',
    'website': 'https://github.com/OCA/project',
    'category': 'Project Management',
    'depends': ['project_template'],
    'data': [
        'views/project.xml',
    ],
    'application': False,
    'installable': True,
    'auto_install': False,
    'license': 'AGPL-3',
    'maintainers': ['nicolasramos'],
    'development_status': 'Beta',
}
